============
Installation
============

At the command line::

    $ easy_install django-isnull-list-filter

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv django-isnull-list-filter
    $ pip install django-isnull-list-filter
